# 2022-08-12 - Child Chain Gauge Reward Helper

Deployment of the `ChildChainGaugeRewardHelper`, a helper contract that can be used to both query and claim child chain gauge tokens instantly, without waiting for the standard one-hour period.

## Useful Files

- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`ChildChainGaugeRewardHelper` artifact](./artifact/ChildChainGaugeRewardHelper.json)
